@@ -4,7 +4,7 @@ use namespace::autoclean;
 
 use Web::ComposableRequest::Constants qw( NUL TRUE );
 use Web::ComposableRequest::Util      qw( extract_lang is_member
-                                          request_config_roles );
+                                          add_config_role );
 use Unexpected::Functions             qw( inflate_placeholders );
 use Unexpected::Types                 qw( ArrayRef CodeRef NonEmptySimpleStr
                                           Undef );
@@ -12,20 +12,28 @@ use Moo::Role;
 
 requires qw( query_params _config _env );
 
-request_config_roles __PACKAGE__.'::Config';
+add_config_role __PACKAGE__.'::Config';
 
 # Attribute constructors
 my $_build_locale = sub {
    my $self   = shift;
+   my $conf   = $self->_config;
    my $locale = $self->query_params->( 'locale', { optional => TRUE } );
 
-   $locale and is_member $locale, $self->_config->locales and return $locale;
+   $locale and is_member $locale, $conf->locales and return $locale;
 
-   for (@{ $self->locales }) {
-      is_member $_, $self->_config->locales and return $_;
+   my $lang; $locale and $lang = extract_lang( $locale )
+      and $lang ne $locale and is_member $lang, $conf->locales and return $lang;
+
+   for my $locale (@{ $self->locales }) {
+      is_member $locale, $conf->locales and return $locale;
    }
 
-   return $self->_config->locale;
+   for my $lang (map { extract_lang $_ } @{ $self->locales }) {
+      is_member $lang, $conf->locales and return $lang;
+   }
+
+   return $conf->locale;
 };
 
 my $_build_locales = sub {
@@ -198,16 +206,10 @@ Defines the following configuration attributes
 
 =over 3
 
-=item C<gettext>
+=item C<l10n_attributes>
 
-A code reference. Defaults to one which returns it's first argument. The first
-argument is the lookup key, the second argument is a hash reference of
-options
-
-=item C<l10n_domain>
-
-A non empty simple string which defaults to F<messages>. The default message
-catalogue
+A hash reference. The C<domains> attribute is an array reference containing
+the default C<gettext> domains
 
 =item C<locale>
 
@@ -233,9 +235,7 @@ substitutions to be quoted
 
    $localised_string = $self->loc( $key, @args );
 
-Translates C<$key> into the required language and substitutes the bind values.
-The C<locale> is currently set in configuration but will be extracted from
-the request in a future release
+Translates C<$key> into the required language and substitutes the bind values
 
 =head2 C<loc_default>
 
